#!/usr/bin/perl -w

# filter: substitutes current version info for existing values in source

use strict;
use warnings;
use v5.020;
use English qw( -no_match_vars );
use autodie qw( :all );

my $verfile  = 'VERSION';

# get version and release date from verfile
open (my $fh, '<', $verfile);
my $ver = <$fh>;
my $rel = <$fh>;
close $fh;
chomp ($ver, $rel);

my $ver_re = qr{
	(?<=                # begin non-matching anchor
		^           ## start of line
		my          ## literal "my"
		\s          ## singe space
		\$VERSION   ## literal "$VERSION"
		\s          ## single space
		\s?         ## optional single space
		=           ## literal equals
		\s          ## single space
		'           ## literal quote (opens the string in source)
		)           ## end anchor
	[.0-9]+             # dot or digits (actual version number to sub)
	(?=                 # begin non-matching anchor
		'           ## literal quote (closes the string in source)
		;           ## literal semicolon
		\s*         ## optional trailing whitespace
		$           ## end of line
		)           ## end anchor
	}x;

my $rel_re = qr{
	(?<=                 # begin non-matching anchor
		^            ## start of line
		my           ## literal "my"
		\s           ## singe space
		\$PROGDATE   ## literal "$VERSION"
		\s           ## single space
		\s?          ## optional single space
		=            ## literal equals
		\s           ## single space
		'            ## literal quote (opens the string in source)
		)            ## end anchor
	[-0-9]+              # dash or digits (actual date to sub)
	(?=                  # begin non-matching anchor
		'            ## literal quote (closes the string in source)
		;            ## literal semicolon
		\s*          ## optional trailing whitespace
		$            ## end of line
		)            ## end anchor
	}x;

while (<>) {
	s/$ver_re/$ver/g;
	s/$rel_re/$rel/g;
	print;
	}
